/*
*  Name:      exceptions.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   UESQLC exceptions
*  Date:      $Date: 2000/02/16 13:34:05 $
*  Revision:  $Revision: 1.14 $
*
*  Copyright (C) 1996-1999  Rafael Jesus Alcantara Perez <rafa@dedalo-ing.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _EXCEPTIONS_UESQLC__
#define _EXCEPTIONS_UESQLC__

#include <mpcl/base_exception.hh>
#include <mpcl/error_exception.hh>
#include <mpcl/fatal_exception.hh>
#include <mpcl/warning_exception.hh>


/**
*  Exception: parent exception class for UESQLC.
*
*  Warning and errors should look like this:
*
*    source-file-name:lineno: message
*/
class TExceptionUESQLC: public virtual mpcl::TBaseException 
{

  protected:

    //
    //  S E L E C T O R S
    //

    void write (ostream& rtTARGET_OSTREAM) const;

};  // class TExceptionUESQLC


///  Exception: general warning.
class TExceptionUESQLC_Warning         :
  private virtual mpcl::TBaseException ,
  public mpcl::TWarningException       ,
  public TExceptionUESQLC
{

  public:

    //
    //  C O N S T R U C T O R S
    //

    /**
    *  Builds the instance with a generic and a (if used) specific description
    *  of the exception.
    *  @param pkcSPECIFIC_DESCRIPTION Specific description.
    *  @param pkcFILE_NAME            File name where the exception has thrown.
    *  @param kiLINE_NUMBER           Line number of the former file.
    */
    TExceptionUESQLC_Warning ( const char* pkcSPECIFIC_DESCRIPTION ,
                               const char* pkcFILE_NAME            ,
                               const int   kiLINE_NUMBER           );

};  // class TExceptionUESQLC_Warning


///  Exception: general error.
class TExceptionUESQLC_Error           :
  private virtual mpcl::TBaseException ,
  public mpcl::TErrorException         ,
  public TExceptionUESQLC
{

  public:

    //
    //  C O N S T R U C T O R S
    //

    /**
    *  Builds the instance with a generic and a (if used) specific description
    *  of the exception.
    *  @param pkcSPECIFIC_DESCRIPTION Specific description.
    *  @param pkcFILE_NAME            File name where the exception has thrown.
    *  @param kiLINE_NUMBER           Line number of the former file.
    */
    TExceptionUESQLC_Error ( const char* pkcSPECIFIC_DESCRIPTION ,
                             const char* pkcFILE_NAME            ,
                             const int   kiLINE_NUMBER           );

};  // class TExceptionUESQLC_Error


/**
*  Exception: compiler runtime error.
*
*  Fatal errors should look like this:
*
*    program:source-file-name:lineno: message
*/
class TExceptionUESQLC_Fatal   :
  private virtual mpcl::TBaseException ,
  public mpcl::TFatalException ,
  public TExceptionUESQLC
{

  protected:

    //
    //  S E L E C T O R S
    //

    void write (ostream& rtTARGET_OSTREAM) const;


  public:

    //
    //  C O N S T R U C T O R S
    //

    /**
    *  Builds the instance with a generic and a (if used) specific description
    *  of the exception.
    *  @param pkcSPECIFIC_DESCRIPTION Specific description.
    *  @param pkcFILE_NAME            File name where the exception has thrown.
    *  @param kiLINE_NUMBER           Line number of the former file.
    */
    TExceptionUESQLC_Fatal ( const char* pkcSPECIFIC_DESCRIPTION      ,
                             const char* pkcFILE_NAME            = "" ,
                             const int   kiLINE_NUMBER           = 0  );

};  // class TExceptionUESQLC_Fatal


#endif  // not _EXCEPTIONS_UESQLC__
